@@ -9,14 +9,16 @@
 #define MOD2_H
 
 /* please include singularconfig.h exclusively via <kernel/mod2.h> and before any other header */
-# include <singularconfig.h>
-# include <misc/auxiliary.h>
+# include "singularconfig.h"
+# include "misc/auxiliary.h"
+
+#define HAVE_SVD
 
 #undef VERSION
-#define VERSION "4.1.0"
+#define VERSION "4.1.1"
 #define SINGULAR_MAJOR_VERSION 4
 #define SINGULAR_MINOR_VERSION 1
-#define SINGULAR_SUB_VERSION 0
+#define SINGULAR_SUB_VERSION 1
 #define S_ROOT_DIR ""
 
 /*******************************************************************
@@ -82,7 +84,7 @@
 #define ALIGN_8
 #endif
 
-#define SINGULAR_PATCHLEVEL 0
+#define SINGULAR_PATCHLEVEL 3
 #define SINGULAR_VERSION ((SINGULAR_MAJOR_VERSION*1000 + SINGULAR_MINOR_VERSION*100 + SINGULAR_SUB_VERSION*10)+SINGULAR_PATCHLEVEL)
 
 /*******************************************************************
@@ -114,7 +116,15 @@
 #define SEEK_SET 0
 #endif
 
-#define HALT() m2_end(2)
+#ifdef __cplusplus
+extern "C" {
+#endif
+void  m2_end(int i);
+#ifdef __cplusplus
+}
+#endif
+
+static inline void HALT() { m2_end(2);}
 
 /* define OLD_RES for res/sres/mres(i,j,k) */
 #undef OLD_RES
@@ -123,17 +133,6 @@
 /* #define MAX_INT_LEN 11 */
 
 
-#ifdef DO_PROFILE
-/* define to enable explicit profiling of some crucial inline
- * routines and defines  */
-#undef DO_DEEP_PROFILE
-#endif
-
-/* define to enable assume */
-#ifndef HAVE_ASSUME
-#undef HAVE_ASSUME
-#endif
-
 /* define LINKAGE to "extern C" if compiling for shared libs */
 #ifndef LINKAGE
 #if defined(PIC)
@@ -154,9 +153,6 @@
 /* undefine to enable inline */
 #define NO_INLINE
 
-/* undefine to disable assume -- should normally be defined for SING_NDEBUG */
-#define HAVE_ASSUME
-
 /* undef PDEBUG to disable checks of polys
 
  define PDEBUG to
@@ -215,7 +211,7 @@
      #define OM_TRACK 5
      #define OM_KEEP  1
      #include "mod2.h"
-     #include <omalloc/omalloc.h>
+     #include "omalloc/omalloc.h"
    ensures that all memory allocs/free in this file are done with
    OM_CHECK==3 and OM_TRACK==5, and that all addresses allocated/freed
    in this file are only marked as free and never really freed.
@@ -243,7 +239,7 @@
        #define OM_TRACK 5
        #define OM_KEEP  1
        #include "mod2.h"
-       #include <omalloc/omalloc.h>
+       #include "omalloc/omalloc.h"
      Under dynamic scope, do (e.g., from within the debugger):
        om_Opts.MinCheck = 3; om_Opts.MinTrack = 5; omOpts.Keep = LONG_MAX;
    + to find out where "memory corruption" occurred, increase value of
@@ -383,10 +379,10 @@ extern void dErrorBreak();
 }
 #endif
 
-#ifndef HAVE_ASSUME
+#ifdef SING_NDEBUG
 #define assume(x) do {} while (0)
 #define r_assume(x) do {} while (0)
-#else /* ! HAVE_ASSUME */
+#else /* SING_NDEBUG */
 
 #define assume_violation(s,f,l) \
   dReportError("assume violation at %s:%d condition: %s", f,l,s)
@@ -414,10 +410,10 @@ do                                              \
   }                                             \
 }                                               \
 while (0)
-#endif /* HAVE_ASSUME */
+#endif /* SING_NDEBUG */
 
 /* do have RDEBUG, unless we are doing the very real thing */
-#ifdef HAVE_ASSUME
+#ifndef SING_NDEBUG
 #ifndef RDEBUG
 #define RDEBUG
 #endif
