@@ -19,7 +19,6 @@
  *
  * REQUIREMENTS:
  * - agreement about the interface to LLL
- * - SINGULAR_4_1
  * - FLINT providing LLL
  * (none of the above is currently true, but all of them is required)
  *
@@ -29,8 +28,8 @@
 #include <flint/flint.h>
 
 #if __FLINT_RELEASE >= 20500
-#include <polys/matpol.h>
-#include <coeffs/bigintmat.h>
+#include "polys/matpol.h"
+#include "coeffs/bigintmat.h"
 #include <flint/fmpz.h>
 #include <flint/fmpq.h>
 #include <flint/fmpz_poly.h>
